/*-
 * Copyright (c) 2008 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by Alistair Crooks (agc@NetBSD.org)
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
#include <sys/types.h>
#include <sys/param.h>

#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include "config.h"
#include "libicb.h"

static void
slowdown(int n)
{
	(void)n;
	printf("slowing down\n");
	icb_setspeed(icb_getspeed() - 1);
}

static void
speedup(int n)
{
	(void)n;
	printf("speeding up\n");
	icb_setspeed(icb_getspeed() + 1);
}

int
main(int argc, char **argv)
{
	icbchan_t	defaults;
	icbchan_t	chan;
	char		buf[MAXPATHLEN];
	int		i;

	(void) memset(&defaults, 0x0, sizeof(defaults));
	defaults.timestamps = 1;
	defaults.colours = 1;
	defaults.id = defaults.nick = getenv("USER");
	defaults.port = 7326;
	defaults.server = strdup("localhost");
	defaults.group = strdup("1");
	defaults.passwd = strdup("");
	defaults.cmdchar = '/';
	icb_setspeed(9);
	(void) signal(SIGUSR1, speedup);
	(void) signal(SIGUSR2, slowdown);
	while ((i = getopt(argc, argv, "Vg:h:n:p:s:v")) != -1) {
		switch(i) {
		case 'V':
			printf("%s ICB messaging client %s\nVersion: %s\n",
				PACKAGE_NAME, PACKAGE_STRING, PACKAGE_VERSION);
			printf("Please send all bug reports to: %s\n",
				PACKAGE_BUGREPORT);
			exit(EXIT_SUCCESS);
			/* NOTREACHED */
		case 'g':
			defaults.group = optarg;
			break;
		case 'h':
			defaults.server = optarg;
			break;
		case 'n':
			defaults.nick = optarg;
			break;
		case 'p':
			defaults.port = atoi(optarg);
			break;
		case 's':
			icb_setspeed(atoi(optarg));
			break;
		case 'v':
			defaults.verbose += 1;
			break;
		default:
			/* XXX */
			break;
		}
	}
	printf("%s ICB client, version %s\n", PACKAGE_NAME, PACKAGE_VERSION);
	printf("All praise, bug reports and chocolate to %s, please\n",
		PACKAGE_BUGREPORT);
	icb_chanopen(&chan, &defaults);
	icb_login(&chan);
	(void) snprintf(buf, sizeof(buf), "%s/.agcbrc", getenv("HOME"));
	icb_rcfile(&chan, buf);
	icb_chat(&chan);
	exit(EXIT_SUCCESS);
}
