/*-
 * Copyright (c) 2008 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by Alistair Crooks (agc@NetBSD.org)
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef LIBICB_H_
#define LIBICB_H_	20080929

#include <regex.h>

enum {
	MAX_TRIGGERS	= 15
};

/* this struct describes a textual trigger */
typedef struct icbpat_t {
	char		*text;	/* regexp to look for */
	regex_t		 r;	/* its compiled form */
} icbpat_t;

/* this struct describes an array of regexs which can grow */
typedef struct icbarray_t {
	int	 	 c;	/* # of elements in the array */
	int		 size;	/* size of array */
	icbpat_t	*v;	/* the array itself */
} icbarray_t;

/* this struct describes an icb channel/group */
typedef struct icbchan_t {
	char		*server;	/* server name */
	char		*group;		/* icb group name */
	int		 sock;		/* socket for comms */
	char		*id;		/* user id */
	char		*nick;		/* nickname */
	char		*passwd;	/* any password */
	int		 port;		/* port to use on server */
	int		 timestamps;	/* print timestamps on output */
	int		 colours;	/* use coloured names on output */
	int		 verbose;	/* be verbose */
	icbarray_t	 triggers;	/* textual triggers to embolden */
	icbarray_t	 filters;	/* textual triggers to ignore */
	char		*permanent;	/* in a conversation with nick */
	char		*prevpersonal;	/* last permanent nick */
	char		 cmdchar;	/* command character */
} icbchan_t;

int icb_chanopen(icbchan_t *, icbchan_t *);
int icb_login(icbchan_t *);
int icb_chat(icbchan_t *);
int icb_rcfile(icbchan_t *, const char *);
int icb_sendopenmsg(icbchan_t *, const char *);

void icb_setspeed(const int);
int icb_getspeed(void);

#endif
