/*-
 * Copyright (c) 2008 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by Alistair Crooks (agc@NetBSD.org)
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/param.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include "libicb.h"

/* stat the file, and note any differences between old and new */
static int
readfile(icbchan_t *chan, char *fname, int sleepsecs)
{
	char	 buf[1024];
	FILE	*fp;

	if ((fp = fopen(fname, "r")) == NULL) {
		(void) fprintf(stderr, "File \"%s\" does not exist\n", fname);
		return 0;
	}
	while (fgets(buf, sizeof(buf), fp) != NULL) {
		icb_sendopenmsg(chan, buf);
		printf("%s", buf);
		sleep(sleepsecs);
	}
	(void) fclose(fp);
	return 1;
}

int
main(int argc, char **argv)
{
	icbchan_t	 defaults;
	icbchan_t	 chan;
	char		*home;
	char		 buf[MAXPATHLEN];
	int		 sleepsecs;
	int		 i;

	(void) memset(&defaults, 0x0, sizeof(defaults));
	defaults.timestamps = 1;
	defaults.colours = 1;
	defaults.id = strdup("agcb");
	defaults.nick = strdup("agc");
	defaults.port = 7326;
	defaults.server = strdup("localhost");
	defaults.group = strdup("prep");
	defaults.passwd = strdup("");
	defaults.cmdchar = '/';
	home = getenv("HOME");
	sleepsecs = 3;
	while ((i = getopt(argc, argv, "g:h:n:p:s:v~:")) != -1) {
		switch(i) {
		case 'g':
			defaults.group = optarg;
			break;
		case 'h':
			defaults.server = optarg;
			break;
		case 'n':
			defaults.nick = optarg;
			break;
		case 'p':
			defaults.port = atoi(optarg);
			break;
		case 's':
			sleepsecs = atoi(optarg);
			break;
		case 'v':
			defaults.verbose += 1;
			break;
		case '~':
			home = optarg;
			break;
		default:
			/* XXX */
			break;
		}
	}
	icb_chanopen(&chan, &defaults);
	icb_login(&chan);
	(void) snprintf(buf, sizeof(buf), "%s/.tailbotrc", home);
	icb_rcfile(&chan, buf);
	for (i = optind ; i < argc ; i++) {
		readfile(&chan, argv[i], sleepsecs);
	}
	exit(EXIT_SUCCESS);
}
